@@ -113,7 +113,7 @@ class FileBox:
     def type(self) -> FileBoxType:
         """get filebox type"""
         return FileBoxType(self._type)
-
+    
     async def ready(self):
         """
         sync the name from remote
@@ -166,6 +166,11 @@ class FileBox:
                 )
 
         json_data = get_json_data(self)
+
+        # make type in the serialized json data
+        if 'type' not in json_data:
+            json_data['type'] = self.type().value
+
         data = json.dumps(json_data, cls=FileBoxEncoder, indent=4)
         return data
 
@@ -270,6 +275,16 @@ class FileBox:
         # if sending the voice file, the mediaType must be: 'audio/silk'
         if file_box.name.endswith('.sil'):
             file_box.mediaType = 'audio/silk'
+            
+            if not file_box.metadata or not file_box.metadata.get('voiceLength', None):
+                logger.warn(
+                    'detect that you want to send voice file, but no voiceLength setting, '
+                    'so use the defualt settign: file_box.metadata = {"voiceLength": 1000}'
+                    'you should set it manually'
+                )
+                file_box.metadata = {
+                    "voiceLength": 1000
+                }
         else:
             file_box.mimeType = mimetypes.guess_type(path)[0] or ''
 
@@ -346,7 +361,7 @@ class FileBox:
 
         # original box_type field name is boxType
         if 'type' not in json_obj:
-            raise Exception('boxType field must be required')
+            raise Exception('box field must be required')
         # assert that boxType value must match the value of FileBoxType values
 
         if json_obj['type'] == FileBoxType.Base64.value:
